@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '0.1.27'
+__version__ = '0.1.28'
 
 from .app import Kola
 from .blueprint import Blueprint
 from .later import Later
-from kola import safe_call, logger
+from kola import safe_call, safe_func, logger
