@@ -4,7 +4,7 @@ import functools
 import gevent
 from gevent.server import StreamServer
 import kola
-from kola import safe_call
+from kola import safe_call, safe_func
 from .connection import Connection
 from .stream import GStream
 
@@ -15,7 +15,6 @@ class Kola(kola.Kola):
 
     def __init__(self, server_class=None, conn_class=None):
         super(Kola, self).__init__()
-        self.repeat_timer_func_list = []
         self.server_class = server_class or StreamServer
         self.conn_class = conn_class or Connection
 
@@ -27,8 +26,9 @@ class Kola(kola.Kola):
             from gevent import monkey
             monkey.patch_all()
 
-        self._start_repeat_timers()
         self.server = self.server_class((host, port), self.handle_stream)
+
+        self._start_repeat_timers()
         self.server.serve_forever()
 
     def register_blueprint(self, blueprint):
@@ -48,7 +48,7 @@ class Kola(kola.Kola):
 
                 return result
 
-            self.repeat_timer_func_list.append(func_wrapper)
+            self.events.repeat_timer += safe_func(func_wrapper)
             return func_wrapper
         return inner_repeat_timer
 
@@ -56,9 +56,6 @@ class Kola(kola.Kola):
         """
         把那些repeat timers启动
         """
-        for func in self.repeat_timer_func_list:
-            safe_call(func)
-        # 执行blueprints
+        self.events.repeat_timer()
         for name, bp in self.blueprints.items():
-            for func in bp.repeat_app_timer_func_list:
-                safe_call(func)
+            bp.events.repeat_app_timer()
