@@ -3,7 +3,7 @@
 import functools
 import gevent
 import kola
-from kola import safe_call
+from kola import safe_call, safe_func
 
 
 class Blueprint(kola.Blueprint):
@@ -13,7 +13,6 @@ class Blueprint(kola.Blueprint):
 
     def __init__(self, name):
         super(Blueprint, self).__init__(name)
-        self.repeat_app_timer_func_list = []
 
     def repeat_app_timer(self, interval):
         """
@@ -29,6 +28,6 @@ class Blueprint(kola.Blueprint):
 
                 return result
 
-            self.repeat_app_timer_func_list.append(func_wrapper)
+            self.events.repeat_app_timer += safe_func(func_wrapper)
             return func_wrapper
         return inner_repeat_timer
